;	===============================================================
;	DWIN.CPY - Drawing Window Data Structure
;	===============================================================
;	Copyright 1995 Evolution Computing
;	All rights reserved
;	Written by Mike Riddle 6-15-95
;	---------------------------------------------------------------

;	sizeof(ViewP) must be multiple of 4 bytes

ViewP		STRUC
VWidth		REAL4	10.0		;current view width
VHgt		REAL4	7.5		;current view height
VCenX		REAL4	5.0		;current view center X
VCenY		REAL4	3.75		;current view center Y
VCenZ		REAL4	0.0		;current view center Z
VRotXY		REAL4	0.0		;current view rotation about XY
VRotYZ		REAL4	0.0		;current view rotation about YZ
VRotZX		REAL4	0.0		;current view rotation about ZX
Nleft		real4	0.0		;normalized 0..1 screen location
Ntop		real4	0.0
Nright		real4	1.0
Nbottom		real4	1.0
VType		dword	0		;view type bits
VName		SBYTE	0		;view name
		db	0		;28 dup (0) causes sizeof()
		db	0		;bugs!
		db	0
		dword	0
		dword	0
		dword	0
		dword	0
		dword	0
		dword	0
ViewP		ends

VSetCt		equ	8		;# dwords to copy for view set
;	---------------------------------------------------------------

DWIN		struc
len		dword	SIZEOF(DWIN)	;record length
hDWin		dword	0		;child win is accessed thru handle
GridF		dword	0		;current grid flags

;	This windows DWIN DevU structure

LocalDevU	DevU	<>		;this windows' DevU structure

;	The OpenGL support data

hDC		dword	0		;hDC for OpenGL
hRC		dword	0		;rendering context

;	Drawing window view specifications

VWidth		REAL4	10.0		;current view width
VHgt		REAL4	7.5		;current view height
VCenX		REAL4	5.0		;current view center X
VCenY		REAL4	3.75		;current view center Y
VCenZ		REAL4	0.0		;current view center Z
VRotXY		REAL4	0.0		;current view rotation about XY
VRotYZ		REAL4	0.0		;current view rotation about YZ
VRotZX		REAL4	0.0		;current view rotation about ZX
Nleft		real4	0.0		;normalized 0..1 screen location
Ntop		real4	0.0
Nright		real4	1.0
Nbottom		real4	1.0
VType		dword	0		;view type bits
VName		SBYTE	0		;view name
		db	0		;32 dup (0) causes sizeof()
		db	0		;bugs!
		db	0
		dword	0
		dword	0
		dword	0
		dword	0
		dword	0
		dword	0

;	Main window client area current DWIN coordinates
;	These values are calc from N values above when
;	the main windows' size changes.

Cleft		dword	0
Ctop		dword	0
Cright		dword	0
Cbottom		dword	0

;	Child (drawing window) client area coordinates
;	These are used by the drawing primitives

Dleft		dword	0
Dtop		dword	0
Dright		dword	0
Dbottom		dword	0

;	Current cursor information

CType		dword	0	;cursor type
CFlags		dword	0	;current RDF flags for this cursor
CAtch		dword	0	;1 = draw pick box also

;	note: the following must match 3d line geometry (CSRMGR)

DWVecX		real4	0.0	;DWVecX..DWOrgZ = 3d "on-line" vector
DWVecY		real4	0.0
DWVecZ		real4	0.0
DWOrgX		real4	0.0	;cursor origin
DWOrgY		real4	0.0
DWOrgZ		real4	0.0
DWCsrX		real4	0.0	;cursor position
DWCsrY		real4	0.0
DWCsrZ		real4	0.0

;	Scroll Bar Information

HSBPos		dword	0	;range 0..100
VSBPos		dword	0	;range 0..100

;	Separate Drawing List Window Information

hDList		dword	0	;0 = normal window
CloseProc	dword	0	;<>0 call proc on window close
LVBkgnd		dword	0	;last valid background color

;	2d Window Information

wxsiz	dword	0		;window pixel sizes
wysiz	dword	0
rxsiz	REAL4	0.0		;real window size
rysiz	REAL4	0.0
rxlow	REAL4	0.0		;real window extents
rylow	REAL4	0.0
rxhi	REAL4	0.0
ryhi	REAL4	0.0
wry	REAL4	0.0		;wysiz/rysiz (vert pixels per real unit)
wrx	REAL4	0.0		;wxsiz/rxsiz (horiz pixels per real unit)

;	3d Window Information

WTM	REAL4	16 dup (0.0)	;real pt to 0..1 clip cube xform (draw)
ITM	REAL4	16 dup (0.0)	;0..1 clip cube to real (dig)
VTM	REAL4	16 dup (0.0)	;real pt to view centric real pt
;				;(view horz = x, vert = y, world scale)
IVTM	REAL4	16 dup (0.0)	;inverse VTM - back to world coord

WFDVX	REAL4	0.0		;window forward direction vector
WFDVY	REAL4	0.0
WFDVZ	REAL4	-1.0
ZDpth	REAL4	10.0		;Z Buffer Real Depth
ZHdl	dword	0		;Z Buffer Memory Handle

DynPak	DPak	<>		;DynTrak data

pDropTarget	dword	0	; hold drop target object
DWIN		ends

;	---------------------------------------------------------------
;	View type bit equates
;	---------------------------------------------------------------

VT_3d		equ	01h		;1 if 3d, else 2d
VT_Persp	equ	02h		;1 if perspective, else ortho
VT_Hide		equ	04h		;1 if 3d hidden surface view
VT_NGrd		equ	08h		;1 if grid display inhibited
VT_FitW		equ	10h		;width sets scale (overrules VT_FitV)
VT_FitH		equ	20h		;height sets scale
VT_Off		equ	8000h		;1 if draw window is off (not drawn)
VT_Max		equ	4000h		;window is maximized
VT_Min		equ	2000h		;window is minimized
VT_ZEXT		equ	1000h		;win needs ZExtSetup on redraw
VT_Render	equ	40h		;render output desired
