;	===============================================================
;	GRIDS.CPY - Grid & Snap systems data structures
;	===============================================================
;
;	Copyright 1994-1999 Evolution Computing
;	All rights reserved
;	Written by Mike Riddle 7-2-94
;		with additional work by
;		Susan Montooth 1/95
;
;	---------------------------------------------------------------
;
GridIBRevised	proto	stdcall
;
;	===============================================================
;	Rectangular grid (supported by GRIDR.ASM)
;	===============================================================

L$RectGS	equ	sizeof(RectGS)

RectGS		struc
RLen		dd	L$RectGS
ID		dw	0
GName		db	32 dup (0)
GClass		dw	0		;RectGS class = 0
AlignX		real4	0.0		;all types of GS have
AlignY		real4	0.0		;len thru AlignZ in same posn
AlignZ		real4	0.0
;
DeltaX		real4	1.0		;GS class-specific data starts
DeltaY		real4	1.0		;with DeltaX
DeltaZ		real4	1.0
SnapN		dw	4
Flags		dw	0
SnapX		real4	0.25
SnapY		real4	0.25
SnapZ		real4	0.25
RectGS		ends

;	values for RectGS.Flags:

RGS_SQUARE	equ	1		;x spacing = y spacing
RGS_TRIGRID	equ	2		;y = x * tan(30) *1.5

;	===============================================================
;	Circular grid (supported by GRIDC.ASM)
;	===============================================================

L$CirGS	equ	sizeof(CirGS)

CirGS		struc
RLen		dd	L$CirGS
ID		dw	0
GName		db	32 dup (0)
GClass		dw	1		;CirGS class = 1
AlignX		real4	0.0		;all types of GS have
AlignY		real4	0.0		;len thru AlignZ in same posn
AlignZ		real4	0.0
;
DeltaA		real4	0.261795	;15 deg
DeltaR		real4	1.0		;with DeltaA
DeltaZ		real4	1.0
SnapN		dw	2
Flags		dw	0
SnapA		real4	0.087265
SnapR		real4	0.3333333
SnapZ		real4	1.0
CirGS		ends

;	===============================================================
;	Angular grid (supported by XPGRIDA.ASM)
;	===============================================================

L$AngGS		equ	sizeof(AngGS)

AngGS		struc
RLen		dd	L$AngGS
ID		dw	0
GName		db	32 dup (0)
GClass		dw	2		;AngGS class = 2
AlignX		real4	0.0		;all types of GS have
AlignY		real4	0.0		;len thru AlignZ in same posn
AlignZ		real4	0.0
;
DeltaX		real4	1.0		;GS class-specific data starts
DeltaY		real4	1.0		;with DeltaX
DeltaZ		real4	1.0
SnapN		dw	4
Flags		dw	0
SnapX		real4	0.25
SnapY		real4	0.25
SnapZ		real4	0.25
;
;	Specify grid workplane in 3d
;
RotXY		real4	0.0		;3d rotation angles for plane
RotYZ		real4	0.0
RotZX		real4	0.0
ODist		real4	0.0		;prp offset dist to plane
;
;	Transforms back and forth
;
W2G		TMat	<>		;world coord to rect grid coord
G2W		TMat	<>		;rect grid to world coord
AngGS		ends

;	values for AngGS.Flags:

AGS_SQUARE	equ	1		;x spacing = y spacing
AGS_3D		equ	4		;1=3d grid, else 2d

;	===============================================================
;	Hex grid (supported by GRIDX.ASM)
;	===============================================================

L$HexGS		equ	sizeof(HexGS)

HexGS		struc
RLen		dd	L$HexGS
ID		dw	0
GName		db	32 dup (0)
GClass		dw	3		;RectGS class = 3
AlignX		real4	0.0		;all types of GS have
AlignY		real4	0.0		;len thru AlignZ in same posn
AlignZ		real4	0.0
;
Wid		real4	1.0		;hex cell width
Hgt		real4	1.154700538	;hex cell height
;
;	calculated cell offsets
;					;vertical	horizontal
hdelta		real4	1.0		;width		width*1.5
vdelta		real4	0.866025403	;width*sin(60)	width*.5
hofst		real4	0.5		;width*.5	width*.75
h1		real4	0.5		;width*.5	width*.25
h2		real4	0.25		;width*.25	width*.375
h3		real4	0.5		;width*.5	width*.5
v1		real4	0.288675134	;height*.25	height*.5
v2		real4	0.433012701	;height*.375	height*.25
v3		real4	0.433012701	;height*.5	height*.5
;
flags		dword	77h		;draw and snap flags
orient		dword	2		;1=horizontal, 2=vertical
HexGS		ends

;	values for HexGS.Flags:

XGS_DXCEN	equ	1		;draw center points
XGS_DXEPT	equ	2		;draw endpoints
XGS_DXMID	equ	4		;draw midpoints
XGS_SXCEN	equ	10h		;snap center points
XGS_SXEPT	equ	20h		;snap endpoints
XGS_SXMID	equ	40h		;snap midpoints

;	===============================================================
;	Grid Information block header
;	===============================================================

IB_GRID		equ	4		;grid info block type #
MaxGS		equ	20		;approx max # grid systems

GBIB		struc
ERLen		dword	SIZEOF (GBIB)	;std info block header
EType		byte	ET_IB		;EType = Info Block
IType		byte	IB_GRID+IB_DFLT	;IB type = Grid
Creator		word	0		;XPID (0=core)
AllocLen	dword	sizeof(GBIB)	;allocation length
flags		word	0		;button flags
NextID		word	2		;next after predefined grids
NextOfst	dword	GBIB.NxtFree-GBIB.ERLen	;offset to next free
CurGridNr	word	0		;current grid instance ID #
CurGridOfst	dword	GBIB.StdRect-GBIB.ERLen	;offset to current GS
StdRect		RectGS	<>		;0: standard rectangular grid
StdCir		CirGS	<>		;1: standard circular grid system
NxtFree		dword	0		;current end marker
GBIB		ends

;	GBIB.flags values

GS_GRID		equ	1		;grid button on/off
GS_SNAP		equ	2		;snap button on/off
GS_CSNAP	equ	4		;cursor snap button on/off
GS_ORTHO	equ	8		;ortho button on//offx

Grid		struc			;generic grid structure
RLen		dd	0
ID		dw	0
GName		db	32 dup (?)
GClass		dw	0
AlignX		real4	0.0
AlignY		real4	0.0
AlignZ		real4	0.0
Grid		ends

;	NOTE: Some drawings do not have a valid dword endmarker
;	written, although it is included in the IB record length.
;	A workaround is to take the IB starting address and add
;	the GBIB.NextOfst value to it. This is the address that
;	should have the dword 0 written to it. Check for this
;	address when scanning - at or above it is the end of
;	the infoblock.
