;	===============================================================
;	IMObject.CPY - IMObject access macros and definitions
;	===============================================================
;	Copyright 2010 Evolution Computing
;	All rights reserved
;	Written by Mike Riddle 13-Jan-2010
;	===============================================================

;	position index in pgp table

hApplication			equ		0
hV8Access				equ		0
hSvc					equ		2
hWebSvc					equ		45

IINFO	struct
pBits		dword	0	; start of bitmap image (adrs of first byte)
pLast		dword	0	; for bounds checking
nPixBytes	dword	0	; nr of bytes in image
nRowSize	dword	0	; nr of bytes per row
nPixSize	dword	0	; nr of bytes per pixel
wid			dword	0	; nr of columns (in pixels)
hgt			dword	0	; nr of lines (in pixels)
hotx		dword	0	; icon hotspot
hoty		dword	0	; y=0 always top of image
fHasAlpha	dword	0	; true if alpha channel data valid
IINFO	ends


;	messages

MSGC_V8ACCESS			equ		1E00h
MSG_v8AlertDlg			equ		MSGC_V8ACCESS+1
MSG_v8URLGet			equ		MSGC_V8ACCESS+111
MSG_v8URLGetData		equ		MSGC_V8ACCESS+112
MSG_v8URLGetError		equ		MSGC_V8ACCESS+113
MSG_v8URLGetImage		equ		MSGC_V8ACCESS+114

MSGC_SVC				equ		0600h
MSG_SvcToUnicode		equ		MSGC_SVC+27
MSG_SvcFromUnicode		equ		MSGC_SVC+28
MSG_SvcFindSubStrW		equ		MSGC_SVC+21
MSG_SvcReplaceW			equ		MSGC_SVC+43

MSGC_IIMAGE				equ		0700h
MSG_ImgInfo				equ		MSGC_IIMAGE+2	;ptr to IINFO
MSG_ImgSaveToFile		equ		MSGC_IIMAGE+60
MSG_ImgSaveToFileA		equ		MSGC_IIMAGE+61
MSG_ImgSaveToMem		equ		MSGC_IIMAGE+62
MSG_ImgSaveToMemA		equ		MSGC_IIMAGE+63

MSGC_WEBSVC				equ		7500h
MSG_WSMakeWebBrowser	equ		MSGC_WEBSVC+2
MSG_WSSetNotify			equ		MSGC_WEBSVC+80
MSG_WSShowURL			equ		MSGC_WEBSVC+60
MSG_WSShowHTML			equ		MSGC_WEBSVC+61

MSG_WSNotifyURL			equ		MSGC_WEBSVC+202
MSG_WSPageNavError		equ		MSGC_WEBSVC+203
MSG_WSNotifyClose		equ		MSGC_WEBSVC+204

MSGC_ISTR				equ		2100h
MSG_SLength				equ		MSGC_ISTR+3
MSG_STextPtr			equ		MSGC_ISTR+4

MSGC_HGTMAP				equ		00001F00h
MSG_HMapBfrAdr			equ		MSGC_HGTMAP+1
MSG_HMapWidth			equ		MSGC_HGTMAP+2
MSG_HMapHeight			equ		MSGC_HGTMAP+3
MSG_HMapMax				equ		MSGC_HGTMAP+4
MSG_HMapMin				equ		MSGC_HGTMAP+5
MSG_HMapOffset			equ		MSGC_HGTMAP+6
MSG_HMapScale			equ		MSGC_HGTMAP+7
MSG_HMapNormalize		equ		MSGC_HGTMAP+8
MSG_HMap2Image			equ		MSGC_HGTMAP+9
MSG_HMapContour			equ		MSGC_HGTMAP+10
MSG_HMapDraw			equ		MSGC_HGTMAP+11
MSG_HMapValueAt			equ		MSGC_HGTMAP+12

;	return codes

IM_RTN_IGNORED			equ		0
IM_RTN_NOTHING			equ		0
IM_RTN_FALSE			equ		0
IM_RTN_TRUE				equ		1
		
;	---------------------------------------------------------------
;	Msg() call macro: (all parms are pushed as 4-byte integers)
;	---------------------------------------------------------------
				
IMMSG	macro	IMOBJ,NMSG,p1,p2,p3,p4,p5,p6,p7,p8,p9
		local	nrargs
		nrargs = 0
	
		IFNB	<p9>
		nrargs = nrargs + 1
		pushd	p9
		ENDIF
		
		IFNB	<p8>
		nrargs = nrargs + 1
		pushd	p8
		ENDIF
		
		IFNB	<p7>
		nrargs = nrargs + 1
		pushd	p7
		ENDIF
		
		IFNB	<p6>
		nrargs = nrargs + 1
		pushd	p6
		ENDIF
		
		IFNB	<p5>
		nrargs = nrargs + 1
		pushd	p5
		ENDIF
		
		IFNB	<p4>
		nrargs = nrargs + 1
		pushd	p4
		ENDIF
		
		IFNB	<p3>
		nrargs = nrargs + 1
		pushd	p3
		ENDIF
		
		IFNB	<p2>
		nrargs = nrargs + 1
		pushd	p2
		ENDIF
		
		IFNB	<p1>
		nrargs = nrargs + 1
		pushd	p1
		ENDIF
				
		pushd	NMSG
		
		IF		(OPATTR (IMOBJ)) AND 00000010y
		mov		ecx,IMOBJ
		ELSE
		mov		ebx,pgp		;call hSvc
		mov		ecx,[ebx]+IMOBJ*4
		ENDIF
		push	ecx			;<this> pointer
		mov		ecx,[ecx]	;vtable ptr
		call	dword ptr [ecx]+4 ;Msg()
		add		esp,(nrargs+2)*4	;pop parameters	
		endm

;	---------------------------------------------------------------
;	hIMObject->Release()
;	---------------------------------------------------------------

IMREL	macro	IMOBJ
		local	fin
		mov		ecx,IMOBJ
		jecxz	fin
		push	ecx			;<this> pointer
		mov		eax,[ecx]	;vtable ptr
		call	dword ptr [eax]+8 ;Release()
		add		esp,4		;pop parameters
fin:	
		endm

;	---------------------------------------------------------------
;	Msg() call macro: parms are pushed with IMPD/IMPQ macros
;	and are pushed in reverse order, last parm first
;	---------------------------------------------------------------

IMMSGN	macro	IMOBJ,NMSG,NARGDWORDS
		pushd	NMSG
		mov		ebx,pgp		;call IMOBJ via pgp
		mov		ecx,[ebx]+IMOBJ*4
		push	ecx			;<this> pointer
		mov		ecx,[ecx]	;vtable ptr
		call	dword ptr [ecx]+4 ;Msg()
		add		esp,(NARGDWORDS+2)*4	;pop parameters	
		endm

IMPD	macro	p
		pushd	p
		endm
		
IMPQ	macro	q
		pushq	q
		endm

IMPGP	macro	reg,IMOBJ
		mov		reg,pgp		;call hSvc
		mov		reg,[reg]+IMOBJ*4
		endm

;	===============================================================
;	Object Class Factories
;	===============================================================

MakeIStr		proto	stdcall,pText:dword
MakeIImage		proto	stdcall,wid:dword,hgt:dword

;	===============================================================
