;	================================================================
;	MATDEF.CPY - Transform Matrix Definitions
;	================================================================
;
;	Copyright (C) 1988-1995 Evolution Computing
;	All rights reserved
;	Written by Mike Riddle 2/6/88
;	Revised 11-6-91 for FCAD 3.0
;	Ken Hill: Added TSPEC2 structure 1/22/93
;	Susan Montooth: Win32 mods 10/27/95
;
;	----------------------------------------------------------------
;	The 2D Transform matrix is fit inside the general 3D matrix:
;
;	M11 | M12 |  xx |  0		Note that no 2D transforms
;	----|-----|-----|----		will change column 4 values.
;	M21 | M22 |  xx |  0		The transform routines take
;	----|-----|-----|----		advantage of this.
;	 xx |  xx |  xx | xx
;	----|-----|-----|----
;	M41 | M42 |  xx |  1
;
;	symbols only need to store the 1st 3 columns as the
;	4th column will always be [ 0 0 0 1] in a symbol.
;	----------------------------------------------------------------
;
MatSiz	equ	64		;matrix size in bytes
PMatSiz	equ	48		;4 rows x 3 columns partial size
;
TMat	STRUC			;identity matrix is default
m11	real4	1.0		;first column
m21	real4	0.0
m31	real4	0.0
m41	real4	0.0
m12	real4	0.0		;second column
m22	real4	1.0
m32	real4	0.0
m42	real4	0.0
m13	real4	0.0		;third column
m23	real4	0.0
m33	real4	1.0
m43	real4	0.0
m14	real4	0.0		;fourth column
m24	real4	0.0
m34	real4	0.0
m44	real4	1.0
TMat	ends
;
SymTMat	STRUC			;SYMBOL TMat (last always [0 0 0 1])
m11	real4	1.0		;first column
m21	real4	0.0
m31	real4	0.0
m41	real4	0.0
m12	real4	0.0		;second column
m22	real4	1.0
m32	real4	0.0
m42	real4	0.0
m13	real4	0.0		;third column
m23	real4	0.0
m33	real4	1.0
m43	real4	0.0
SymTMat	ends
;
TSpec2	STRUC
ScaleX	real4	0.0		;scale x by factor
ScaleY	real4	0.0		;scale y by factor (negative if mirrored)
ShearYX real4	0.0		;shear y to vector ShearYX,ShearYY
ShearYY real4	0.0
Rotate	real4	0.0
DeltaX	real4	0.0		;move by DeltaX, DeltaY
DeltaY	real4	0.0
TSpec2	ENDS
;
TSpec3	STRUC
ScaleX	real4	0.0		;scale x by factor
ScaleY	real4	0.0		;scale y by factor (negative if mirrored)
ScaleZ	real4	0.0
ShearYX real4	0.0		;shear y to vector ShearYX,ShearYY
ShearYY real4	0.0
ShearYZ	real4	0.0
RotXY	real4	0.0		;rotate planes
RotYZ	real4	0.0
RotZX	real4	0.0
DeltaX	real4	0.0		;move by DeltaX, DeltaY
DeltaY	real4	0.0
DeltaZ	real4	0.0
TSpec3	ENDS
;
;	3d CTM components in terms of a 2D work plane
WPSpec	STRUC
RZX	real4	0.0		;Rotations in various planes
RYZ	real4	0.0
RXY	real4	0.0
OrgX	real4	0.0		;work plan origin in space
OrgY	real4	0.0
OrgZ	real4	0.0
ScaleX	real4	0.0		;scale x by factor
ScaleY	real4	0.0		;scale y by factor (negative if mirrored)
ShearYX real4	0.0		;shear y to vector ShearYX,ShearYY
ShearYY real4	0.0
WPSpec	ENDS
;
SYMDEEP		equ	32	;depth of nested symbol stack

