// 	===============================================================
// 	FSTYLES.CPY - Fill Style Structures
// 	===============================================================

// 	Copyright 1996 Evolution Computing
// 	All rights reserved
// 	Written by Mike Riddle 12-1-96

// 	===============================================================
// 	FSTYIB: Fill Styles Information block header
// 	===============================================================

// 	CurHdr.FStyle = the currently selected style ID
// 	It determines the currently selected fill style

#ifndef _FSTYLES_H_
#define _FSTYLES_H_

#define CurFSTYIBVer	1			// current version #

// 	===============================================================
// 	Individual FSTY style definitions
// 	===============================================================

#define FS_PAT			0			// brush pattern style
#define FS_HATCH		1			// metric hatch style
#define FS_BMP			2			// bitmap file style
#define FS_SYM			3			// symbol fill style

typedef struct
{
	DWORD	RLen;					// style record length in bytes
	char	fstype;					// style type id (FS_XXXX)
	char	dofst;					// # bytes from rlen to data start
	WORD	ID;						// fill style id (magic cookie)
	char	flags;					// options flags
	char	fsname[10];				// ANSIZ fill style name
}FSTY;

// 	Values for FSTY.flags:

#define FS_OUTL				 1	// outline the filled shape
#define FS_TRANS		0x80	// transparent color specified

// 	---------------------------------------------------------------
// 	Pattern styles have an 8 byte bitmap following the FSTY header
// 	---------------------------------------------------------------

/*
PatSty		macro	id,nm
		local	epat,spat
spat		dword	(epat-spat)+8
		sbyte	FS_PAT
		sbyte	(epat-spat)
		word	id
		sbyte	FS_OUTL
		sbyte	nm
		sbyte	0
epat		label	byte
		endm
*/

// 	---------------------------------------------------------------
// 	Hatch Styles have 4*SIZEOF(HATCH) hatch data following the header
// 	---------------------------------------------------------------

typedef struct
{
	WORD	lsty;				// 0 = solid line
	float	siz;				// 0.0 = this set not drawn
	float	ang;				// line bearing angle
	float	xofst;			// offset to start of line draw
	float	yofst;			// (only affects styled lines)
}HATCH;

#define NrHatch		4

/*
HatchSty	macro	id,nm
		local	epat,spat
spat		dword	(epat-spat)+(NrHatch*SIZEOF(HATCH))
		sbyte	FS_HATCH
		sbyte	(epat-spat)
		word	id
		sbyte	FS_OUTL
		sbyte	nm
		sbyte	0
epat		label	byte
		endm
*/

// 	---------------------------------------------------------------
// 	Bitmap styles: data
// 	---------------------------------------------------------------

typedef struct
{
	char	fit;					// fit code      = 	FS_EXPFILL
	char	tcolor;				// transparent color
	char	bmpname[1];		// bmp file name (ANSIZ)
}BMPSTY;

/*
BmpSty		macro	id,nm,fit,fn
		local	epat,spat,fpat
spat		dword	(fpat-spat)
		sbyte	FS_BMP
		sbyte	(epat-spat)
		word	id
		sbyte	FS_OUTL
		sbyte	nm
		sbyte	0
epat		label	byte
		db	fit
		db	0
		sbyte	fn
		sbyte	0
fpat		label	byte
		endm
*/

// 	Bitmap fit code values

#define FS_TILE				1
#define FS_EXPFILL		2
#define FS_EXPFIT			3
#define FS_COPY				4

// 	---------------------------------------------------------------
// 	Symbol Styles
// 	---------------------------------------------------------------

typedef struct
{
	float	xstep;					// repeat stepping distance
	float	ystep;
	float	xscale;					// individual copy tforms
	float	yscale;
	float	xyrot;
	char	symname[1];			// bmp file name (ANSIZ)
}SYMSTY;

/*
SymSty		macro	id,nm,fit,fn
		local	epat,spat,fpat
spat		dword	(fpat-spat)
		sbyte	FS_SYM
		sbyte	(epat-spat)
		word	id
		sbyte	FS_OUTL
		sbyte	nm
		sbyte	0
epat		label	byte
		real4	1.0
		real4	1.0
		real4	1.0
		real4	1.0
		real4	0.0
		sbyte	fn
		sbyte	0
fpat		label	byte
		endm
*/



typedef struct
{
	DWORD	ERLen;			// std info block header    		= SIZEOF(FSTYIB)
	char	EType;			// EType = Info Block     			= ET_IB
	char	IType;			// IB type = Fill Styles    		=	IB_FSTYLE
	WORD	Creator;		// XPID (0=core)
	DWORD	AllocLen;		// allocation length (0=ERLen)

	WORD	IBVer;			// FSTYIB version id  					= CurFSTYIBVer
	WORD	NextID;			// next ID to use     					=	256


	FSTY  FS[1];			// fill style instance data starts here
							// A record length of 0 ends the list
}FSTYIB;


#endif
