// 	===============================================================
// 	GRIDS.CPY - Grid & Snap systems data structures
// 	===============================================================
// 
// 	Copyright 1994-1995 Evolution Computing
// 	All rights reserved
// 	Written by Mike Riddle 7-2-94
// 		with additional work by
// 		Susan Montooth 1/95
// 
//	===============================================================

void XPCALL GridIBRevised(void);

// 	===============================================================
// 	Rectangular grid (supported by GRIDR.ASM)
// 	===============================================================

#define L_RECTGS	sizeof(RECTGS)

typedef struct
{
	DWORD	RLen;
	WORD	ID;
	char	GName[32];
	WORD	GClass;				// RectGS class = 0
	float	AlignX;				// all types of GS have
	float	AlignY;				// len thru AlignZ in same posn
	float	AlignZ;

	float	DeltaX;				// GS class-specific data starts
	float	DeltaY;				// with DeltaX
	float	DeltaZ;
	WORD	SnapN;
	WORD	Flags;
	float	SnapX;
	float	SnapY;
	float	SnapZ;
}RECTGS;

// 	values for RectGS.Flags:
#define RGS_SQUARE	1		// x spacing = y spacing
#define RGS_TRIGRID	2		// y = x * tan(30) *1.5

// 	===============================================================
// 	Circular grid (supported by GRIDC.ASM)
// 	===============================================================

#define L_CIRGS		sizeof(CIRGS)

typedef struct
{
	DWORD	RLen;
	WORD	ID;
	char	GName[32];
	WORD	GClass;				// CirGS class = 1
	float	AlignX;				// all types of GS have
	float	AlignY;				// len thru AlignZ in same posn
	float	AlignZ;
 
	float	DeltaA;			
	float	DeltaR;		
	float	DeltaZ;
	WORD	SnapN;
	WORD	Flags;
	float	SnapA;
	float	SnapR;
	float	SnapZ;
}CIRGS;

// 	===============================================================
// 	Angular grid (supported by XPGRIDA.ASM)
// 	===============================================================

#define L_ANGGS		sizeof(ANGGS)

typedef struct
{
	DWORD	RLen;
	WORD	ID;
	char	GName[32];
	WORD	GClass;				// AngGS class = 2
	float	AlignX;				// all types of GS have
	float	AlignY;				// len thru AlignZ in same posn
	float	AlignZ;
 
	float	DeltaX;				// GS class-specific data starts
	float	DeltaY;				// with DeltaX
	float	DeltaZ;
	WORD	SnapN;
	WORD	Flags;
	float	SnapX;
	float	SnapY;
	float	SnapZ;
 
	// 	Specify grid workplane in 3d
 
	float	RotXY;				// 3d rotation angles for plane
	float	RotYZ;
	float	RotZX;
	float	ODist;				// prp offset dist to plane

	// 	Transforms back and forth
 
	TMAT W2G;		// world coord to rect grid coord
	TMAT G2W;		// rect grid to world coord
}ANGGS;

// 	values for AngGS.Flags:

#define AGS_SQUARE		1		// x spacing = y spacing
#define AGS_3D				4		// 1=3d grid, else 2d


// 	===============================================================
// 	Grid Information block header
// 	===============================================================

//#define IB_GRID		 4		// grid info block type #
#define MaxGS			20		// approx max # grid systems

typedef struct
{
	DWORD	ERLen;					// std info block header
	char	EType;					// EType = Info Block
	char	IType;					// IB type = Grid					 IB_GRID+IB_DFLT	
	WORD	Creator;				// XPID (0=core)
	DWORD	AllocLen;				// allocation length
	WORD	flags;					// button flags
	WORD	NextID;       	// next after predefined grids
	DWORD	NextOfst;		    // offset to next free:   GBIB.NxtFree-GBIB.ERLen
	WORD	CurGridNr;		  // current grid instance ID #
	DWORD	CurGridOfst;		// offset to current GS:   GBIB.StdRect-GBIB.ERLen
	RECTGS	StdRect;			// 0: standard rectangular grid
	CIRGS		StdCir;				// 1: standard circular grid system
	DWORD	 NxtFree;				// current end marker
}GBIB;

// 	GBIB.flags values

#define GS_GRID			1		// grid button on/off
#define GS_SNAP			2		// snap button on/off
#define GS_CSNAP		4		// cursor snap button on/off
#define GS_ORTHO		8		// ortho button on//offx

typedef struct		// generic grid structure
{
	DWORD	RLen;
	WORD	ID;
	char	GName[32];
	WORD	GClass;		
	float	AlignX;		
	float	AlignY;		
	float	AlignZ;
}GRID;
